@@ -1,7 +1,6 @@
 setClass("STS", # space-time partial 
   contains = "ST", 
-  #slots = c(index = "matrix"),
-  representation(index = "matrix"),
+  slots = c(index = "matrix"),
   validity = function(object) {
     stopifnot(ncol(object@index) == 2)
 	ix = unique(object@index[,1]) # space
@@ -14,8 +13,7 @@ setClass("STS", # space-time partial
 
 setClass("STSDF", # space-time partial data frame
   contains = "STS", 
-  #slots = c(data = "data.frame"),
-  representation(data = "data.frame"),
+  slots = c(data = "data.frame"),
   validity = function(object) {
 	stopifnot(nrow(object@index) == nrow(object@data))
     #stopifnot(ncol(object@index) == 2)
